@@ -43,9 +43,10 @@ class Decider(Actor):
 
     def poll(self, task_list=None,
              identity=None,
-             maximum_page_size=None):
-        """Polls for decision tasks to process from current
-        actor's instance defined ``task_list``
+             **kwargs):
+        """
+        Polls a decision task and returns the token and the full history of the
+        workflow's events.
 
         :param task_list: task list to poll for decision tasks from.
         :type task_list: string
@@ -55,26 +56,41 @@ class Decider(Actor):
         workflow history.
         :type identity: string
 
-        :param maximum_page_size: The maximum number of history events
-        returned in each page. The default is 100.
-        :type maximum_page_size: integer
-
-        :returns: polled decision tasks
+        :returns: (token, history)
         :type: swf.models.History
+
         """
         task_list = task_list or self.task_list
 
-        events = self.connection.poll_for_decision_task(
+        task = self.connection.poll_for_decision_task(
             self.domain.name,
             task_list=task_list,
             identity=identity,
-            maximum_page_size=maximum_page_size
+            **kwargs
         )
-
-        if not 'taskToken' in events:
+        token = task.get('taskToken')
+        if token is None:
             raise PollTimeout("Decider poll timed out")
 
-        history = History.from_event_list(events['events'])
-        task_token = events['taskToken']
+        events = task['events']
 
-        return task_token, history
+        next_page = task.get('nextPageToken')
+        while next_page:
+            task = self.connection.poll_for_decision_task(
+                self.domain.name,
+                task_list=task_list,
+                identity=identity,
+                next_page_token=next_page,
+                **kwargs
+            )
+
+            token = task.get('taskToken')
+            if token is None:
+                raise PollTimeout("Decider poll timed out")
+
+            events.extend(task['events'])
+            next_page = task.get('nextPageToken')
+
+        history = History.from_event_list(events)
+
+        return token, history
